======================
The 1d histogram pages
======================

Individual marginalized 1d histograms can be seen on the
`1d histogram pages <https://pesummary.github.io/GW190412/html/IMRPhenomPv3HM_IMRPhenomPv3HM_mass_1_source.html>`_.
This page includes the marginalized histogram with 5th and 95th percentiles
displayed by blue dashed lines and the median and uncertainty (90% symmetric
credible interval) at the top of the plot. We see the scatter plot showing
the evolution of the collected samples for `mass_1_source` as well as a plot
showing the autocorrelation function for `mass_1_source`. This plot is commonly
used to check for randomness in the data. An autocorrelation of 1/-1 means that
the samples are correlated and 0 means no correlation. The autocorrelation
function at a lag of N gives the correlation between the 0th sample and the Nth
sample. If you click on the 1d histogram you will see that the plot changes to
provide the CDF.

If you are only interested in this marginalized posterior, you may download
only these samples as a `dat` file by clicking on the export to dat button.

If you wish to see multiple marginalized posterior distributions on a single
page, you may either visit the
`custom page <https://pesummary.github.io/GW190412/html/IMRPhenomPv3HM_IMRPhenomPv3HM_Custom.html>`_
or the `all page <https://pesummary.github.io/GW190412/html/IMRPhenomPv3HM_IMRPhenomPv3HM_All.html>`_.
The custom page allows the user to select only the parameters they
are interested in. Like the `single analysis corner page <../IMRPhenomPv3HM/corner.html>`
_,
the parameters are either selected via the side bar or typed manually in the
search bar. The all page will show the marginalized 1d histograms for all
parameters that are in the provided result file.
